@@ -17,25 +17,26 @@ package main
 import (
 	"flag"
 
-	"github.com/golang/glog"
 	"github.com/google/cadvisor/utils/oomparser"
+	"k8s.io/klog"
 )
 
 // demonstrates how to run oomparser.OomParser to get OomInstance information
 func main() {
+	klog.InitFlags(nil)
 	flag.Parse()
 	// out is a user-provided channel from which the user can read incoming
 	// OomInstance objects
 	outStream := make(chan *oomparser.OomInstance)
 	oomLog, err := oomparser.New()
 	if err != nil {
-		glog.Infof("Couldn't make a new oomparser. %v", err)
+		klog.Infof("Couldn't make a new oomparser. %v", err)
 	} else {
 		go oomLog.StreamOoms(outStream)
 		// demonstration of how to get oomLog's list of oomInstances or access
 		// the user-declared oomInstance channel, here called outStream
 		for oomInstance := range outStream {
-			glog.Infof("Reading the buffer. Output is %v", oomInstance)
+			klog.Infof("Reading the buffer. Output is %v", oomInstance)
 		}
 	}
 }
